==> _bazel_codegen-0.1.3.tar.gz: lib/src/assets/file_system.dart <==
// Copyright (c) 2017, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
import 'dart:convert';
import 'dart:io';

import 'package:path/path.dart' as p;
import 'package:glob/glob.dart';

class BazelFileSystem {
  final String workspaceDir;
  final List<String> searchPaths;

  BazelFileSystem(this.workspaceDir, this.searchPaths) {
    if (workspaceDir == null) throw new ArgumentError();
    if (searchPaths == null) throw new ArgumentError();
  }

  //TODO(nbosch) replace with async version
  bool existsSync(String path) {
    for (var searchPath in searchPaths) {
      var f = new File(p.join(workspaceDir, searchPath, path));
      if (f.existsSync()) return true;
    }
    return false;
  }

  //TODO(nbosch) replace with async version
  List<int> readAsBytesSync(String path) =>
      _fileForPath(path).readAsBytesSync();

  //TODO(nbosch) replace with async version
  String readAsStringSync(String path, {Encoding encoding: UTF8}) =>
      _fileForPath(path).readAsStringSync(encoding: encoding ?? UTF8);

  Iterable<String> findAssets(String packagePath, Glob glob) sync* {
    for (var searchPath in searchPaths) {
      var fullPath = p.join(workspaceDir, searchPath, packagePath);
      if (!new Directory(fullPath).existsSync()) continue;
      yield* glob
          .listSync(root: fullPath)
          .map((e) => e.path)
          .map((path) => p.relative(path, from: fullPath));
    }
  }

  File _fileForPath(String path) {
    for (var searchPath in searchPaths) {
      var f = new File(p.join(workspaceDir, searchPath, path));
      if (f.existsSync()) return f;
    }
    throw new FileSystemException('File not found', path);
  }
}

==> _bazel_codegen-0.3.1.tar.gz: lib/src/assets/file_system.dart <==
// Copyright (c) 2017, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
import 'dart:async';
import 'dart:io';

import 'package:path/path.dart' as p;
import 'package:glob/glob.dart';

/// A filesystem that can search for paths under multiple roots.
class BazelFileSystem {
  final String workspaceDir;
  final List<String> searchPaths;

  BazelFileSystem(this.workspaceDir, this.searchPaths) {
    if (workspaceDir == null) throw new ArgumentError();
    if (searchPaths == null) throw new ArgumentError();
  }

  Future<bool> exists(String path) async => (await _fileForPath(path)) != null;

  Future<File> find(String path) async {
    var file = await _fileForPath(path);
    if (file == null) throw new FileSystemException('File not found', path);
    return file;
  }

  Iterable<String> findAssets(String packagePath, Glob glob) sync* {
    for (var searchPath in searchPaths) {
      var fullPath = p.join(workspaceDir, searchPath, packagePath);
      if (!new Directory(fullPath).existsSync()) continue;
      yield* glob
          .listSync(root: fullPath)
          .map((e) => e.path)
          .map((path) => p.relative(path, from: fullPath));
    }
  }

  Future<File> _fileForPath(String path) async {
    for (var searchPath in searchPaths) {
      var f = new File(p.join(workspaceDir, searchPath, path));
      if (await f.exists()) return f;
    }
    return null;
  }
}
